WebSocket debug

{ "id": 1, "type": "subscribe_events", "event_type": "state_changed" }

    Examples:
    {
      "id": 2, "type": "subscribe_events", "event_type": "state_changed"
    }

    {
      "id": 3, "type": "call_service", "domain": "light", "service": "turn_off"
    }

    {
      "id": 4, "type": "unsubscribe_events", "subscription": 2
    }

    {
      "id": 5, "type": "get_states"
    }

    {
      "id": 6, "type": "get_config"
    }

    {
      "id": 7, "type": "get_services"
    }

    {
      "id": 8, "type": "get_panels"
    }